


Introduction
------------

This package estimates causal parameters of different identification strageries.


.. code:: python

    from causalinf import did

    est = did.estimate("y~did")
    est.summary()
